// CkHttpResponse.h: interface for the CkHttpResponse class.
//
//////////////////////////////////////////////////////////////////////

#ifndef _CkHttpResponse_H
#define _CkHttpResponse_H

#pragma once

class CkString;
class CkByteData;

/*
    IMPORTANT: Objects returned by methods as non-const pointers must be deleted
    by the calling application. 

  */

#include "CkObject.h"

// CLASS: CkHttpResponse
class CkHttpResponse  : public CkObject
{
    private:
	void *m_impl;
	bool m_utf8;	// If true, all input "const char *" parameters are utf-8, otherwise they are ANSI strings.

	// Don't allow assignment or copying these objects.
	CkHttpResponse(const CkHttpResponse &) { } 
	CkHttpResponse &operator=(const CkHttpResponse &) { return *this; }

    public:
	void *getImpl(void) { return m_impl; } 

	CkHttpResponse(void *impl) : m_impl(impl) { }

	CkHttpResponse();
	virtual ~CkHttpResponse();

	// BEGIN PUBLIC INTERFACE
	bool get_Utf8(void) const;
	void put_Utf8(bool b);

	void get_Header(CkString &str);
	void get_Body(CkByteData &data);
	void get_BodyStr(CkString &str);
	void get_StatusLine(CkString &str);
	int get_StatusCode(void);
	void get_Charset(CkString &str);
	void get_Domain(CkString &str);
	int get_ContentLength(void);
	void get_Date(SYSTEMTIME &sysTime);

	// Get header field by name.
	void GetHeaderField(const char *fieldName, CkString &str);
	void GetHeaderFieldAttr(const char *fieldName, const char *attrName, CkString &str);
	
	int get_NumHeaderFields(void);
	void GetHeaderName(int index, CkString &str);
	void GetHeaderValue(int index, CkString &str);

	// Methods to get Set-Cookie headers.
	int get_NumCookies(void);
	void GetCookieDomain(int index, CkString &str);
	void GetCookiePath(int index, CkString &str);
	void GetCookieExpiresStr(int index, CkString &str);
	void GetCookieExpires(int index, SYSTEMTIME &sysTime);
	void GetCookieName(int index, CkString &str);
	void GetCookieValue(int index, CkString &str);


	// Error log retrieval and saving (these methods are common to all Chilkat VC++ classes.)
	//bool SaveLastError(const char *filename);
        //void LastErrorXml(CkString &str);
        //void LastErrorHtml(CkString &str);
        //void LastErrorText(CkString &str);

	// END PUBLIC INTERFACE


};


#endif


