// CkMime.h: interface for the CkMime class.
//
//////////////////////////////////////////////////////////////////////

#ifndef _CKMIME_H
#define _CKMIME_H

#pragma once

class CkMime;
class CkEmail;
class CkString;
class CkCSP;
class CkCert;
class CkByteData;
#include "CkObject.h"

// CLASS: CkMime
class CkMime  : public CkObject
{
    private:
	void *m_impl;
	bool m_utf8;	// If true, all input "const char *" parameters are utf-8, otherwise they are ANSI strings.

	// Don't allow assignment or copying these objects.
	CkMime(const CkMime &) { } 
	CkMime &operator=(const CkMime &) { return *this; }

    public:
	void *getImpl(void) { return m_impl; } 

	CkMime(void *impl);

	CkMime();
	virtual ~CkMime();

	// BEGIN PUBLIC INTERFACE
	bool get_Utf8(void) const;
	void put_Utf8(bool b);


	void get_Version(CkString &str);

	// Error log retrieval and saving (these methods are common to all Chilkat VC++ classes.)
	bool SaveLastError(const char *filename);
        void LastErrorXml(CkString &str);
        void LastErrorHtml(CkString &str);
        void LastErrorText(CkString &str);

	bool SetBodyFromPlainText(const char *str);
	bool SetHeaderField(const char *name, const char *value);
	bool GetHeaderField(const char *name, CkString &value);

	bool GetHeaderFieldName(int index, CkString &fieldName);
	bool GetHeaderFieldValue(int index, CkString &fieldValue);

	void SetVerifyCert(CkCert *cert);

	bool LoadMimeFile(const char *fileName);
	bool LoadMime(const char *mimeMsg);
	bool SaveMime(const char *filename);

	CkEmail *ToEmailObject(void);

	long get_NumParts(void);
	CkMime *GetPart(long index);
	void get_Protocol(CkString &str);
	void put_Protocol(const char *newVal);
	void get_Micalg(CkString &str);
	void put_Micalg(const char *newVal);
	void get_Boundary(CkString &str);
	void put_Boundary(const char *newVal);
	void get_Name(CkString &str);
	void put_Name(const char *newVal);
	void get_Filename(CkString &str);
	void put_Filename(const char *newVal);
	void get_Charset(CkString &sb);
	void put_Charset(const char *newVal);
	void get_Disposition(CkString &str);
	void put_Disposition(const char *newVal);
	void get_Encoding(CkString &str);
	void put_Encoding(const char *newVal);
	void get_ContentType(CkString &str);
	void put_ContentType(const char *newVal);

	bool UnlockComponent(const char *unlockCode);
	bool IsUnlocked(void) const;

	long get_NumHeaderFields(void);

	long get_NumSignerCerts(void);
	long get_NumEncryptCerts(void);
	bool get_UnwrapExtras(void);
	void put_UnwrapExtras(bool newVal);

	bool SetCSP(CkCSP *csp);
	bool AppendPart(CkMime *mime);
	bool AppendPartFromFile(const char *filename);
	bool NewMultipartMixed();
	bool NewMultipartRelated();
	bool NewMultipartAlternative();
	bool NewMessageRfc822(CkMime &mimeObject);

	bool SaveBody(const char *filename);
	bool IsMultipart(void);
	bool IsPlainText(void);
	bool IsHtml(void);
	bool IsXml(void);
	bool IsSigned(void);
	bool IsEncrypted(void);
	bool IsMultipartMixed(void);
	bool IsMultipartAlternative(void);
	bool IsMultipartRelated(void);
	bool IsAttachment(void);
	bool IsText(void);
	bool IsApplicationData(void);
	bool IsImage(void);
	bool IsAudio(void);
	bool IsVideo(void);
	bool GetBodyBinary(CkByteData &db);
	bool GetBodyEncoded(CkString &encodedBody);
	bool GetBodyDecoded(CkString &decodedBody);
	bool SetBodyFromEncoded(const char *encoding, const char *str);
	bool SetBodyFromHtml(const char *str);
	bool SetBodyFromXml(const char *str);
	bool SetBodyFromBinary(CkByteData &dbuf);
	bool SetBodyFromFile(const char *fileName);
	bool Encrypt(CkCert *cert);
	bool ConvertToSigned(CkCert *cert);
	bool AddDetachedSignature(CkCert *cert);
	bool SaveXml(const char *filename);
	bool GetMime(CkString &mime);
	bool LoadXml(const char *xml);
	bool GetXml(CkString &xml);
	CkCert *GetEncryptCert(long index);
	CkCert *GetSignerCert(long index);
	bool UnwrapSecurity(void);
	bool LoadXmlFile(const char *fileName);

	void GetEntireHead(CkString &str);
	void GetEntireBody(CkString &str);

	bool RemovePart(int index);

	// Returns true if the MIME message or any sub-parts
	// are encrypted.
	bool ContainsEncryptedParts(void);
	// Returns true if the MIME message or any sub-parts
	// are signed.
	bool ContainsSignedParts(void);

	// END PUBLIC INTERFACE

};


#endif


